===============
``referencing``
===============

|PyPI| |Pythons| |CI| |pre-commit|

.. |PyPI| image:: https://img.shields.io/pypi/v/referencing.svg
  :alt: PyPI version
  :target: https://pypi.org/project/referencing/

.. |Pythons| image:: https://img.shields.io/pypi/pyversions/referencing.svg
  :alt: Supported Python versions
  :target: https://pypi.org/project/referencing/

.. |CI| image:: https://github.com/python-jsonschema/referencing/workflows/CI/badge.svg
  :alt: Build status
  :target: https://github.com/python-jsonschema/referencing/actions?query=workflow%3ACI

.. |ReadTheDocs| image:: https://readthedocs.org/projects/referencing/badge/?version=stable&style=flat
   :alt: ReadTheDocs status
   :target: https://referencing.readthedocs.io/en/stable/

.. |pre-commit| image:: https://results.pre-commit.ci/badge/github/python-jsonschema/referencing/main.svg
  :alt: pre-commit.ci status
  :target: https://results.pre-commit.ci/latest/github/python-jsonschema/referencing/main


A (very early) playground for exploring:

    * the budding JSON `reference specification(s) <https://github.com/json-schema-org/referencing>`_ (currently housed within the JSON Schema organization but intended to be more broadly applicable)

    * a newer / better integration of reference resolution into `jsonschema <https://pypi.org/project/jsonschema/>`_, likely built on top of the more generic interface which will come out of the above

What's here (if any of it even functions) is highly experimental and will change.
